(function () {
  'use strict';

  window.Drupal = {};
  window.Drupal.Cloud = {};

  const colors = [
    ['#edf8e9', '#bae4b3', '#74c476', '#31a354', '#006d2c'],
    ['#e9f8f4', '#b3e4dc', '#74c1c4', '#317fa3', '#003f6d'],
  ];

  const AXIS_HEIGHT = 10;
  const AXIS_FONT_SIZE = '8';
  const CHART_HEIGHT = 20;
  const TITLE_FONT_SIZE = 10;
  const TITLE_POSITION_X = 1;
  const TITLE_POSITION_Y = 70;
  const BACKGROUND_DEFAULT_COLOR = 'rgba(0, 0, 0, 0)';

  // Draw Chart Function.
  window.Drupal.Cloud.drawChart = function (data, first) {
    data.forEach(function (item, idx) {
      // Delete current chart.
      if (document.querySelector(item.selector)) {
        document.querySelector(item.selector).innerHTML = '';
      }

      // Draw charts.
      if (first && idx === 0) {
        // Delete the axis.
        const xAxis = document.querySelector('#x-axis');
        if (xAxis && xAxis.parentNode) {
          xAxis.parentNode.removeChild(xAxis);
        }

        // Add <div> for the axis.
        const xAxisDiv = document.createElement('div');
        xAxisDiv.id = 'x-axis';
        const chartContainer = document.querySelector(item.selector);
        if (chartContainer && chartContainer.parentNode) {
          chartContainer.parentNode.insertBefore(xAxisDiv, chartContainer);
        }

        // Draw charts.
        const axis = new HorizonChart();
        axis.setHeight(AXIS_HEIGHT);
        axis.setDataSet(item.values);
        axis.setSelector('#x-axis');
        axis.draw();

        const chartg = document.querySelectorAll('#x-axis g:first-child');
        if (chartg && chartg.style) {
          chartg.style.display = 'none';
        }
        const axisg = document.querySelectorAll('#x-axis .axis');
        if (axis && axisg.style) {
          axisg.style.fontSize = AXIS_FONT_SIZE;
        }
      }

      // Draw charts.
      const horizonChart = new HorizonChart();
      const fontColor = window.getComputedStyle(document.querySelector(item.selector)).color;

      let bgColor = '';
      let parents = document.querySelectorAll(item.selector).parents;
      if (parents) {
        for (let i = 0; i < parents.length; i++) {
          console.log(window.getComputedStyle(parents[i]).backgroundColor);
          let color = window.getComputedStyle(parents[i]).backgroundColor;
          if (color && color !== BACKGROUND_DEFAULT_COLOR) {
            bgColor = color;
            break;
          }
        }
      }
      horizonChart.setTitle(item.id);
      horizonChart.setTitleFontSize(TITLE_FONT_SIZE);
      horizonChart.setTitlePosition(TITLE_POSITION_X, TITLE_POSITION_Y);
      horizonChart.setTitleColer(fontColor);
      horizonChart.setHeight(CHART_HEIGHT);
      horizonChart.setDataSet(item.values);
      horizonChart.setSelector(item.selector);
      horizonChart.setColors(colors[idx % 2]);
      horizonChart.setShowXScale(false);
      horizonChart.draw();

      const g = document.querySelectorAll(item.selector + ' svg g');
      const title = document.querySelectorAll(item.selector + ' svg text');
      const bbox = document.querySelectorAll(item.selector + ' svg text')[0].getBBox();

      const rect = document.createElement('rect');
      rect.setAttribute('x', bbox.x - 1);
      rect.setAttribute('y', bbox.y);
      rect.setAttribute('width', bbox.width + 2);
      rect.setAttribute('height', bbox.height);
      rect.setAttribute('fill', bgColor);
      rect.style.opacity = '0.8';
      if (g) {
        g.insertBefore(rect, item.selector + ' svg text');
      }

      document.querySelector(item.selector).style.marginBottom = '0';

      if (!first || idx > 0) {
        document.querySelector(item.selector).style.borderTop = '1px solid #ddd';
      }
    });
  };
})();
